@@ -23,5 +23,5 @@ BUNDLES_SINGLE_FILES = ()
 BUNDLES_TAG_HTML = {
     'js': '<script src="%(file_url)s"></script>',
     'css': '<link href="%(file_url)s" type="text/css" rel="stylesheet"%(attrs)s />',
-    'less': '<link href="%(file_url)s" type="text/less" rel="stylesheet"%(attrs)s />',
-}
\ No newline at end of file
+    'less': '<link href="%(file_url)s" type="text/less" rel="stylesheet/less"%(attrs)s />',
+}
